@@ -6,7 +6,7 @@ use warnings FATAL => 'all';
 use Mouse;
 use MouseX::Types::Enum (
     APPLE  => { name => 'Apple', color => 'red' },
-    ORANGE => { name => 'Cherry', color => 'red' },
+    ORANGE => { name => 'Orange', color => 'orange' },
     BANANA => { name => 'Banana', color => 'yellow', has_seed => 0 }
 );
 
